@@ -1,10 +1,11 @@
 import argparse
 
 from eda_report.document import ReportDocument
+from eda_report.gui import EDAGUI
 from eda_report.read_file import df_from_file
 
 
-def process_cli_args(*args) -> argparse.Namespace:
+def process_cli_args() -> argparse.Namespace:
     """Captures and parses input from the command line interface using the
     :mod:`argparse` module from the Python standard library.
 
@@ -14,12 +15,19 @@ def process_cli_args(*args) -> argparse.Namespace:
         A class with parsed arguments as attributes.
     """
     parser = argparse.ArgumentParser(
-        prog="eda_cli",
-        description="Automatically analyse data and generate reports.",
+        prog="eda-report",
+        description=(
+            "Automatically analyse data and generate reports. A graphical user"
+            " interface will be launched if none of the optional arguments is "
+            "specified."
+        ),
     )
 
     parser.add_argument(
-        "infile", type=df_from_file, help="A .csv or .xlsx file to analyse."
+        "-i",
+        "--infile",
+        type=df_from_file,
+        help="A .csv or .xlsx file to analyse.",
     )
 
     parser.add_argument(
@@ -50,35 +58,45 @@ def process_cli_args(*args) -> argparse.Namespace:
             "The target variable (dependent feature), used to color-code "
             "plotted values. An integer value is treated as a column index, "
             "whereas a string is treated as a column label."
-            " (Default: %(default)s)"
         ),
     )
 
     # Parse arguments
-    if args:
-        return parser.parse_args(args)
-    else:
-        return parser.parse_args()
+    return parser.parse_args()
 
 
-def run_from_cli():  # pragma: no cover
+def run_from_cli():
     """Creates an exploratory data analysis report in *Word* format using input
     from the command line interface.
 
     This is the function executed when the package is run as a script (using
-    ``python -m eda_report``. It is also the entry point for the ``eda_cli``
-    console script (command).
+    ``python -m eda_report``). It is also the entry point for the
+    ``eda-report`` command (console script).
+
+    Running the ``eda-report`` command without any arguments launches the
+    graphical user interface.
 
     Arguments passed from the command line are captured using the
-    :func:`~eda_report.cli.process_cli_args` function, and then supplied to the
-    :class:`~eda_report.document.ReportDocument` object to generate the report.
+    :func:`~eda_report.cli.process_cli_args` function, and then used to create
+    a :class:`~eda_report.document.ReportDocument` object.
+
+    Example
+    --------
+    .. literalinclude:: examples.txt
+       :lines: 60-83
     """
     args = process_cli_args()
 
-    ReportDocument(
-        args.infile,
-        title=args.title,
-        graph_color=args.color,
-        output_filename=args.outfile,
-        target_variable=args.target,
-    )
+    if args.infile is None:
+        # Launch graphical user interface to select and analyse a file
+        app = EDAGUI()
+        app.mainloop()
+
+    else:
+        return ReportDocument(
+            args.infile,
+            title=args.title,
+            graph_color=args.color,
+            output_filename=args.outfile,
+            target_variable=args.target,
+        )
